# salmongis


[![image](https://img.shields.io/pypi/v/salmongis.svg)](https://pypi.python.org/pypi/salmongis)
[![image](https://img.shields.io/conda/vn/conda-forge/salmongis.svg)](https://anaconda.org/conda-forge/salmongis)


**A geospatial package**


-   Free software: MIT License
-   Documentation: https://GISCreations.github.io/salmongis
    

## Features

-   TODO
